@@ -3,11 +3,10 @@ use strict;
 use warnings;
 
 use WWW::CurlOO ();
-use Exporter ();
+use Exporter 'import';
 
 *VERSION = \*WWW::CurlOO::VERSION;
 
-our @ISA = qw(Exporter);
 our @EXPORT_OK = grep /^CURL/, keys %{WWW::CurlOO::Form::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
@@ -79,18 +78,26 @@ exported upon request.
 
  use WWW::CurlOO::Form qw(:constants);
 
-=head1 METHODS
+=head2 CONSTRUCTOR
 
 =over
 
-=item CLASS->new( [BASE] )
+=item new( [BASE] )
 
 Creates new WWW::CurlOO::Form object. If BASE is specified it will be used
 as object base, otherwise an empty hash will be used. BASE must be a valid
 reference which has not been blessed already. It will not be used by the
 object.
 
-=item OBJECT->add( CURLFORM_option => DATA, ... )
+ my $form = WWW::CurlOO::Form->new( [qw(my very private data)] );
+
+=back
+
+=head2 METHODS
+
+=over
+
+=item add( CURLFORM_option => DATA, ... )
 
 Adds new section to form object. See L<curl_formadd(3)> for more info.
 B<WARNING: currently some option combination may crash your perl.>
@@ -102,8 +109,7 @@ CURLFORM_FILE, CURLFORM_CONTENTTYPE, CURLFORM_FILENAME.
 Unlike in libcurl function, there is no need to add CURLFORM_END as the last
 argument.
 
-On error this method dies with message: "curl_formadd() failed: $CURLFORMcode\n",
-where $CURLFORMcode is a decimal number.
+On error this method dies with WWW::CurlOO::Form::Code error object.
 
 Options CURLFORM_COPYNAME and CURLFORM_COPYCONTENTS automatibally set
 appropriate their length values (CURLFORM_NAMELENGTH and CURLFORM_CONTENTSLENGTH
@@ -147,7 +153,7 @@ an CURL_FORMADD_OPTION_TWICE exception will occur.
  );
 
 
-=item OBJECT->get( [BUFFER / FH / USERDATA], [CALLBACK] )
+=item get( [BUFFER / FH / USERDATA], [CALLBACK] )
 
 Use it to serialize the form object. Normally there is no need to use it
 because WWW::CurlOO::Easy will serialize it while uploading data.
@@ -193,7 +199,7 @@ serialization will be aborted.
 
  sub cb_serial
  {
-     my ( $form, $data, $userdata ) = @_;
+     my ( $form, $data, $uservar ) = @_;
 
      # do anything you want
 
@@ -205,7 +211,7 @@ serialization will be aborted.
 
 Calls L<curl_formget(3)>.
 
-=item OBJECT->DESTROY( )
+=item DESTROY( )
 
 Cleans up. It should not be called manually.
 
@@ -213,7 +219,9 @@ Calls L<curl_formfree(3)>.
 
 =back
 
-=head1 FUNCTIONS
+=head2 FUNCTIONS
+
+None of those functions are exported, you must use fully qualified names.
 
 =over
 
@@ -222,8 +230,30 @@ Calls L<curl_formfree(3)>.
 Return a string for error code CODE.
 String is extracted from error constant name.
 
+ my $message = WWW::CurlOO::Form->strerror(
+     WWW::CurlOO::Form::CURL_FORMADD_OPTION_TWICE
+ );
+
 =back
 
+=head2 CONSTANTS
+
+=over
+
+=item CURLFORM_*
+
+Most of those constants can be used in add() method.
+
+=item CURL_FORMADD_*
+
+If add() fails it will return one of those values.
+
+=back
+
+=head2 CALLBACKS
+
+Callback for get() is described already in L</"use a callback"> subsection.
+
 =head1 SEE ALSO
 
 L<WWW::CurlOO>
